@@ -199,12 +199,13 @@ impl<Metadata: for<'a> Deserialize<'a>> Manifest<Metadata> {
 
             let has_path = self.lib.as_ref().map_or(false, |l| l.path.is_some());
             if !has_path && src.contains("lib.rs") {
+                let old_lib = self.lib.take().unwrap_or_default();
                 self.lib = Some(Product {
                     name: Some(package.name.replace("-", "_")),
                     path: Some("src/lib.rs".to_string()),
                     edition: Some(package.edition),
                     crate_type: Some(vec!["rlib".to_string()]),
-                    ..Product::default()
+                    ..old_lib
                 })
             }
 
@@ -344,7 +345,7 @@ pub struct Product {
 
     /// If the product is meant to be a "macros 1.1" procedural macro, this field must
     /// be set to true.
-    #[serde(default)]
+    #[serde(default, alias = "proc_macro", alias = "proc-macro")]
     pub proc_macro: bool,
 
     /// If set to false, `cargo test` will omit the `--test` flag to rustc, which
